@@ -25,6 +25,7 @@
 #include "ephy-file-helpers.h"
 
 #include "ephy-debug.h"
+#include "ephy-flatpak-utils.h"
 #include "ephy-prefs.h"
 #include "ephy-profile-utils.h"
 #include "ephy-settings.h"
@@ -141,11 +142,12 @@ ephy_file_get_downloads_dir (void)
   download_dir = g_settings_get_string (EPHY_SETTINGS_STATE,
                                         EPHY_PREFS_STATE_DOWNLOAD_DIR);
 
-  if (g_str_equal (download_dir, "Desktop"))
-    download_dir = ephy_file_desktop_dir ();
-  if (g_str_equal (download_dir, "Downloads") ||
-      g_path_is_absolute (download_dir) != TRUE)
+  if (!g_strcmp0 (download_dir, "Downloads") ||
+      !g_path_is_absolute (download_dir) ||
+      ephy_is_running_inside_flatpak ())
     download_dir = ephy_file_download_dir ();
+  else if (!g_strcmp0 (download_dir, "Desktop"))
+    download_dir = ephy_file_desktop_dir ();
 
   return download_dir;
 }
