@@ -1458,6 +1458,12 @@ load_secrets_cb (SecretService   *service,
   }
 
   value = secret_item_get_secret ((SecretItem *)res->data);
+  if (!value) {
+    g_warning ("Failed to retrieve the value of the sync secrets");
+    message = _("The sync secrets for the current sync user are invalid.");
+    goto out_error;
+  }
+
   node = json_from_string (secret_value_get_text (value), &error);
   if (error) {
     g_warning ("Sync secrets are not a valid JSON: %s", error->message);
@@ -1563,7 +1569,7 @@ ephy_sync_service_store_secrets (EphySyncService *self)
   while (g_hash_table_iter_next (&iter, &key, &value))
     json_object_set_string_member (object, key, value);
   json_node_set_object (node, object);
-  json_string = json_to_string (node, TRUE);
+  json_string = json_to_string (node, FALSE);
 
   secret = secret_value_new (json_string, -1, "text/plain");
   attributes = secret_attributes_build (EPHY_SYNC_SECRET_SCHEMA,
